﻿///<reference path="../typings/globals/core-js/index.d.ts"/>
import * as wjcCore from 'wijmo/wijmo';
import * as wjcData from 'wijmo/wijmo.odata';
import * as wjcNav from 'wijmo/wijmo.nav';

// Angular
import { Component, EventEmitter, Input, Inject, enableProdMode, NgModule, ViewChild, AfterViewInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
import { BrowserModule } from '@angular/platform-browser';
import { FormsModule } from '@angular/forms';
import { WjNavModule } from 'wijmo/wijmo.angular2.nav';
import { TabsModule } from './components/AppTab';

'use strict';

// The Explorer application root component.
@Component({
    selector: 'app-cmp',
    templateUrl: 'src/app.html'
})
export class AppCmp implements AfterViewInit {
    items = [];
    editableItems = [];
    isAnimated = true;
    autoCollapse = true;
    expandOnClick = true;
    useCustomCss = true;
    navItem = '';
    chkStatus = '';
    isEditing: boolean;

    @ViewChild('tvEdit') tvEdit: wjcNav.TreeView;

    private _saveCheckedItems: any;
    private _nwindService = 'http://services.odata.org/V4/Northwind/Northwind.svc';

    constructor() {
        this.items = this._getItems();
        this.editableItems = JSON.parse(JSON.stringify(this.items));
    }

    ngAfterViewInit() {

    }

    // editing support
    nodeEditStarting(sender: wjcNav.TreeView, e: wjcNav.TreeNodeEventArgs) {
        if (e.node.hasChildren) {
            e.cancel = true;
        }
        else if (e.node.dataItem.id != undefined) {
            e.node.element.children[1].style.display = "none";
            e.node.element.children[2].style.display = "none";

            var input1 = document.createElement("input");
            input1.value = e.node.dataItem.header;
            input1.ondblclick = function () { "return false" };
            e.node.element.appendChild(input1);

            var input2 = document.createElement("input");
            input2.value = e.node.dataItem.id
            input2.ondblclick = function () { "return false" };
            e.node.element.appendChild(input2);

            this.isEditing = true;
        }
    }

    nodeEditEnding(sender: wjcNav.TreeView, e: wjcNav.TreeNodeEventArgs) {
        if (e.node.dataItem.id != undefined) {
            if (!this.isEditing) {
                var element = e.node.element;
                var input1 = element.children[3];
                var input2 = element.children[4];
                e.node.dataItem.header = input1.value;
                e.node.dataItem.id = input2.value;

                element.children[1].style.display = "inline";
                element.children[2].style.display = "inline";
                element.children[2].innerHTML = input2.value;
                element.removeChild(input1);
                element.removeChild(input2);
            }
            else
                e.cancel = true;
        }
    }

    selectedItemChanged(sender: wjcNav.TreeView, e: wjcNav.TreeNodeEventArgs) {
        if (this.isEditing) {
            this.isEditing = false;
            this.tvEdit.finishEditing(true);
        }
    }

    // custom item
    formatItem(treeView: wjcNav.TreeView, e: wjcNav.FormatNodeEventArgs) {
        if (e.dataItem.id != undefined) {
            e.element.innerHTML += " <span class='wj-node-text' contenteditable='false' autocomplete='off' autocorrect='off' style=''>" + e.dataItem.id + "</span>";
        }
    }

    private _getItems() {
        return [
            {
                header: 'Electronics', img: 'resources/electronics.png', items: [
                    { header: 'Trimmers/Shavers' },
                    { header: 'Tablets' },
                    {
                        header: 'Phones', img: 'resources/phones.png', items: [
                            { header: 'Apple', id: "ID00001" },
                            { header: 'Motorola', id: "ID00002" },
                            { header: 'Nokia', id: "ID00003" },
                            { header: 'Samsung', id: "ID00004" }
                        ]
                    },
                    { header: 'Speakers', newItem: true },
                    { header: 'Monitors' }
                ]
            },
            {
                header: 'Toys', img: 'resources/toys.png', items: [
                    { header: 'Shopkins' },
                    { header: 'Train Sets' },
                    { header: 'Science Kit', newItem: true },
                    { header: 'Play-Doh' },
                    { header: 'Crayola' }
                ]
            },
            {
                header: 'Home', img: 'resources/home.png', items: [
                    { header: 'Coffeee Maker' },
                    { header: 'Breadmaker', newItem: true },
                    { header: 'Solar Panel', newItem: true },
                    { header: 'Work Table' },
                    { header: 'Propane Grill' }
                ]
            }
        ];
    }
}


@NgModule({
    imports: [WjNavModule, BrowserModule, TabsModule, FormsModule],
    declarations: [AppCmp],
    bootstrap: [AppCmp]
})
export class AppModule {
}

enableProdMode();
// Bootstrap application 
platformBrowserDynamic().bootstrapModule(AppModule);